#region ... Copyright  2005 Roland Weigelt ...
/*
This software is provided 'as-is', without any expressed or
implied warranty. In no event will the author be held liable
for any damages arising from the use of this software.

Permission is granted to anyone to use this software for any
purpose, including commercial applications, and to alter it and
redistribute it freely, subject to the following restrictions:

1.	The origin of this software must not be misrepresented; you
	must not claim that you wrote the original software. If you
	use this software in a product, an acknowledgment in the
	product documentation is required.
	
2.	Altered source versions must be plainly marked as such, and
	must not be misrepresented as being the original software.
	
3.	This notice may not be removed or altered from any source
	or altered source distribution.

Copyright  2005 Roland Weigelt (info@roland-weigelt.de)
*/
#endregion

using System;
using System.Collections;
using System.ComponentModel;
using System.Configuration.Install;
using System.Diagnostics;
using Microsoft.Win32;

namespace Weigelt.LastBoxStanding
{
	/// <summary>
	/// Installer for the serivce
	/// </summary>
	[RunInstaller(true)]
	public class ProjectInstaller : System.Configuration.Install.Installer
	{
		private System.ServiceProcess.ServiceProcessInstaller m_objServiceProcessInstaller;
		private System.ServiceProcess.ServiceInstaller m_objServiceInstaller;

		private System.ComponentModel.Container components = null;

		/// <summary> 
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region ... Install / Uninstall ...

		/// <summary>
		/// Performs the installation.
		/// </summary>
		/// <param name="stateServer"></param>
		public override void Install(IDictionary stateServer)
		{
			try
			{
				base.Install(stateServer);
				using (RegistryKey objKey = Registry.LocalMachine.OpenSubKey(@"System\CurrentControlSet\Services\" + this.m_objServiceInstaller.ServiceName, true))
				{
					objKey.SetValue("Description", "Pings a configurable list of machines in your LAN to determine whether at least one of them is still running. If no machine responds, the service performs a custom action, e.g. a shutdown.");
				}
			}
			catch(Exception exc)
			{
				Console.WriteLine("An exception was thrown during installation of the LastBoxStanding service:\n" + exc.ToString());
			}
		}		

		/// <summary>
		/// Removes the installation.
		/// </summary>
		/// <param name="stateServer"></param>
		public override void Uninstall(IDictionary stateServer)
		{
			try
			{
				Process.Start("net", "stop lastboxstanding"); // just in case the service is still running
			}
			catch(Exception exc)
			{
				EventLog.WriteEntry(
					"Application",
					String.Format("Exception encountered while uninstalling the LastBoxStanding service:\n" + exc.ToString()),
					EventLogEntryType.Error);
			}
			finally
			{
				base.Uninstall(stateServer);
			}
		}

		#endregion

		#region ... Component Designer generated code ...
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.m_objServiceProcessInstaller = new System.ServiceProcess.ServiceProcessInstaller();
			this.m_objServiceInstaller = new System.ServiceProcess.ServiceInstaller();
			// 
			// m_objServiceProcessInstaller
			// 
			this.m_objServiceProcessInstaller.Account = System.ServiceProcess.ServiceAccount.LocalSystem;
			this.m_objServiceProcessInstaller.Password = null;
			this.m_objServiceProcessInstaller.Username = null;
			// 
			// m_objServiceInstaller
			// 
			this.m_objServiceInstaller.ServiceName = "LastBoxStanding";
			this.m_objServiceInstaller.StartType = System.ServiceProcess.ServiceStartMode.Automatic;
			// 
			// ProjectInstaller
			// 
			this.Installers.AddRange(new System.Configuration.Install.Installer[] {
																					  this.m_objServiceProcessInstaller,
																					  this.m_objServiceInstaller});

		}
		#endregion

		#region ... Constructor ...

		/// <summary>
		/// Creates a new <see cref="ProjectInstaller"/> instance.
		/// </summary>
		public ProjectInstaller()
		{
			InitializeComponent();
		}

		#endregion
	}
}
