#region ... Copyright  2005 Roland Weigelt ...
/*
This software is provided 'as-is', without any expressed or
implied warranty. In no event will the author be held liable
for any damages arising from the use of this software.

Permission is granted to anyone to use this software for any
purpose, including commercial applications, and to alter it and
redistribute it freely, subject to the following restrictions:

1.	The origin of this software must not be misrepresented; you
	must not claim that you wrote the original software. If you
	use this software in a product, an acknowledgment in the
	product documentation is required.
	
2.	Altered source versions must be plainly marked as such, and
	must not be misrepresented as being the original software.
	
3.	This notice may not be removed or altered from any source
	or altered source distribution.

Copyright  2005 Roland Weigelt (info@roland-weigelt.de)
*/
#endregion

using System;

namespace Weigelt.LastBoxStanding
{
	/// <summary>
	/// Contains the configuration for an action to be performed by the service.
	/// </summary>
	public class ActionConfiguration
	{
		private string m_strName;
		private string m_strExecutable;
		private string m_strArguments;

		/// <summary>
		/// Gets the name of the action.
		/// </summary>
		public string Name
		{
			get { return m_strName; }
		}

		/// <summary>
		/// Gets or sets the full file path of the executable to start.
		/// </summary>
		public string Executable
		{
			get { return m_strExecutable; }
			set { m_strExecutable=value; }
		}

		/// <summary>
		/// Gets or sets the command line arguments for the executable.
		/// </summary>
		public string Arguments
		{
			get { return m_strArguments; }
			set { m_strArguments=value; }
		}

		#region ... Constructor ...

		/// <summary>
		/// Creates an empty <see cref="ActionConfiguration"/> instance.
		/// </summary>
		/// <param name="name">Name of the action</param>
		public ActionConfiguration(string name)
		{
			m_strName=name;
			m_strExecutable=null;
			m_strArguments=null;
		}

		/// <summary>
		/// Creates a new <see cref="ActionConfiguration"/> instance.
		/// </summary>
		/// <param name="name">Name of the action</param>
		/// <param name="executable">The executable to start when the action is performed.</param>
		/// <param name="arguments">The command line arguments for the executable</param>
		public ActionConfiguration(string name, string executable, string arguments)
		{
			m_strName=name;
			m_strExecutable=executable;
			m_strArguments=arguments;
		}
		#endregion
	}
}
