#region ... Copyright  2005 Roland Weigelt ...
/*
This software is provided 'as-is', without any expressed or
implied warranty. In no event will the author be held liable
for any damages arising from the use of this software.

Permission is granted to anyone to use this software for any
purpose, including commercial applications, and to alter it and
redistribute it freely, subject to the following restrictions:

1.	The origin of this software must not be misrepresented; you
	must not claim that you wrote the original software. If you
	use this software in a product, an acknowledgment in the
	product documentation is required.
	
2.	Altered source versions must be plainly marked as such, and
	must not be misrepresented as being the original software.
	
3.	This notice may not be removed or altered from any source
	or altered source distribution.

Copyright  2005 Roland Weigelt (info@roland-weigelt.de)
*/
#endregion

using System;
using System.Collections;
using System.Collections.Specialized;

namespace Weigelt.LastBoxStanding
{
	/// <summary>
	/// Contains the configuration for the service.
	/// </summary>
	public class ServiceConfiguration
	{
		private const int _DefaultCheckInterval=5; // 5 minutes
		private const int _DefaultCheckRetries=2;

		private StringCollection m_colMachineNames=new StringCollection();
		private ActionConfiguration m_objActionWhenLastRemaining=null;

		private int m_nCheckInterval=_DefaultCheckInterval;
		private int m_nCheckRetries=_DefaultCheckRetries;

		private bool m_bSimulateActions=false;
		private bool m_bVerbose=false;

		/// <summary>
		/// Gets the collection of machines that are monitored
		/// be the watcher.
		/// </summary>
		public StringCollection MonitoredMachines
		{
			get { return m_colMachineNames; }
		}

		/// <summary>
		/// Gets the check interval in minutes.
		/// </summary>
		/// <value>Number of minutes</value>
		public int CheckInterval
		{
			get { return m_nCheckInterval; }
			set
			{
				m_nCheckInterval=value;
				if (m_nCheckInterval<0)
					m_nCheckInterval=_DefaultCheckInterval;
			}
		}

		/// <summary>
		/// Gets the number of check retries.
		/// </summary>
		/// <value>Number of retries</value>
		public int CheckRetries
		{
			get { return m_nCheckRetries; }
			set
			{
				m_nCheckRetries=value;
				if (m_nCheckRetries<0)
					m_nCheckRetries=_DefaultCheckRetries;
			}
		}

		/// <summary>
		/// Gets or sets a value indicating whether actions will only be simulated.
		/// </summary>
		public bool SimulateActions
		{
			get { return m_bSimulateActions; }
			set { m_bSimulateActions=value; }
		}

		/// <summary>
		/// Gets or sets a value indicating whether output to the event log will be verbose.
		/// </summary>
		public bool Verbose
		{
			get { return m_bVerbose; }
			set { m_bVerbose=value; }
		}

		/// <summary>
		/// Gets or sets the action to be performed when the local machine is the
		/// last remaining, i.e. all monitored machines are down
		/// (after at least one of them has been running at some point).
		/// </summary>
		/// <value>
		/// The <see cref="ActionConfiguration"/> or <c>null</c> if no action
		/// is to be performed.
		/// </value>
		public ActionConfiguration ActionWhenLastRemaining
		{
			get { return m_objActionWhenLastRemaining; }
			set { m_objActionWhenLastRemaining=value; }
		}

		#region ... Constructor ...

		/// <summary>
		/// Creates a new <see cref="ServiceConfiguration"/> instance.
		/// </summary>
		public ServiceConfiguration()
		{
		}

		#endregion
	}
}
