#region ... Copyright  2005 Roland Weigelt ...
/*
This software is provided 'as-is', without any expressed or
implied warranty. In no event will the author be held liable
for any damages arising from the use of this software.

Permission is granted to anyone to use this software for any
purpose, including commercial applications, and to alter it and
redistribute it freely, subject to the following restrictions:

1.	The origin of this software must not be misrepresented; you
	must not claim that you wrote the original software. If you
	use this software in a product, an acknowledgment in the
	product documentation is required.
	
2.	Altered source versions must be plainly marked as such, and
	must not be misrepresented as being the original software.
	
3.	This notice may not be removed or altered from any source
	or altered source distribution.

Copyright  2005 Roland Weigelt (info@roland-weigelt.de)
*/
#endregion

using System;

namespace Weigelt.LastBoxStanding.Test
{
	/// <summary>
	/// Summary description for SimulatedMachineMonitor.
	/// </summary>
	public class SimulatedMachineMonitor : MachineMonitor
	{
		/// <summary>
		/// Name of a simulated machine that is always on
		/// </summary>
		public const string AlwaysOff="AlwaysOff";

		/// <summary>
		/// Name of a simulated machine that is always off
		/// </summary>
		public const string AlwaysOn="AlwaysOn";

		/// <summary>
		/// Name of a simulated machine that is toggling
		/// between off and on (starting with off).
		/// </summary>
		public const string OffAndOn="OffAndOn";

		/// <summary>
		/// Name of simulated machine A.
		/// </summary>
		public const string MachineA="MachineA";

		/// <summary>
		/// Name of simulated machine B.
		/// </summary>
		public const string MachineB="MachineB";

		/// <summary>
		/// Flag indicating whether simulated machine A is running.
		/// </summary>
		public bool MachineARunning=true;

		/// <summary>
		/// Flag indicating whether simulated machine B is running.
		/// </summary>
		public bool MachineBRunning=true;

		/// <summary>
		/// Flag indication whether simulated machine "OffAndOn" is running.
		/// </summary>
		private bool m_bOffAndOnRunning=false;

		/// <summary>
		/// Determines whether the specified machine is running.
		/// </summary>
		/// <param name="machine">
		/// One of the following machine names:
		/// <list type="bullets">
		/// <item>"AlwaysOff"</item>
		/// <item>"AlwaysOn"</item>
		/// <item>"MachineA"</item>
		/// <item>"MachineB"</item>
		/// </list>
		/// </param>
		public override bool IsMachineRunning(string machine)
		{
			bool bMachineIsRunning=false;
			switch (machine)
			{
				case AlwaysOn:
					bMachineIsRunning=true;
					break;
				case MachineA:
					bMachineIsRunning=this.MachineARunning;
					break;
				case MachineB:
					bMachineIsRunning=this.MachineBRunning;
					break;
				case OffAndOn:
					bMachineIsRunning=m_bOffAndOnRunning;
					m_bOffAndOnRunning^=true;
					break;
			}
			return bMachineIsRunning;
		}

		/// <summary>
		/// Creates a new <see cref="SimulatedMachineMonitor"/> class.
		/// </summary>
		public SimulatedMachineMonitor()
		{
		}
	}
}
